"mass" <-
  function(...) {
    new("mass", ...)
  }
